@@ -16,7 +16,7 @@ from climetlab.indexing import PerUrlIndex
 from ..config import baseurl
 from ..utils import convert_to_datetime
 
-__version__ = "0.1.1"
+__version__ = "0.1.7"
 
 _terms_of_use = """By downloading data from this dataset, you agree to the terms and conditions defined at
 
@@ -56,11 +56,14 @@ class TrainingDataForecast(Dataset):
         self.year = ""
         self.month = ""
         self.step = []
+        
+    def to_xarray(self, **kwargs):
+        return self.source.to_xarray(xarray_open_dataset_kwargs={"backend_kwargs": {"ignore_keys": ["dataType"]}}, **kwargs)
 
     def get_observations_as_xarray(self, fcs_kwargs=None, **obs_kwargs):
         if fcs_kwargs is None:
             fcs_kwargs = dict()
-        fcs = self.source.to_xarray(**fcs_kwargs)
+        fcs = self.source.to_xarray(xarray_open_dataset_kwargs={"backend_kwargs": {"ignore_keys": ["dataType"]}}, **fcs_kwargs)
         fcs_valid_time = fcs.valid_time.to_pandas()
         fcs_time_list = list(map(convert_to_datetime, fcs_valid_time.iloc[0, :]))
         days = dict()
@@ -72,9 +75,15 @@ class TrainingDataForecast(Dataset):
             if day not in days[year_month]:
                 days[year_month].append(day)
 
+        if isinstance(self.parameter, (tuple, list)):  # fix for cin observations bug in the dataset, should be solved later at the analysis dataset level
+            parameters = [param for param in self.parameter if param != "cin"]
+        elif self.parameter == "cin":
+            parameters = ""
+        else:
+            parameters = self.parameter
         sources_list = list()
         for year_month in days:
-            request = {"param": self.parameter,
+            request = {"param": parameters,
                        "date": days[year_month],
                        # Parameters passed to the filename mangling
                        "url": self._BASEURL,
@@ -169,8 +178,9 @@ class TrainingDataForecastSurface(TrainingDataForecast):
         "EU_forecast_{kind}_{leveltype}_params_{isodate}_0.grb"
     )
 
-    _surf_parameters = ["2t", "10u", "10v", "tcc", "100u", "100v", "cape", "stl1", "sshf", "slhf",
-                        "tcw", "tcwv", "swvl1", "ssr", "str", "sd", "cp", "cin", "ssrd", "strd", "vis", "all"]
+    _surf_parameters = ["2t", "10u", "10v", "tcc", "100u", "100v", "cape", "stl1", "sd",
+                        "tcw", "tcwv", "swvl1", "vis", "all"]
+    _surf_parameters += ["cin"]
 
     @normalize("parameter", _surf_parameters)
     @normalize("date", "date(%Y%m%d)")
@@ -305,23 +315,38 @@ class TrainingDataForecastSurfacePostProcessed(TrainingDataForecast):
         "EU_forecast_{kind}_{leveltype}_params_{isodate}_0.grb"
     )
 
-    _surf_pp_parameters = ["tp", "10fg6", "mn2t6", "mx2t6"]
+    _surf_pp_parameters = ["tp", "sshf", "slhf", "ssr", "str", "cp", "ssrd", "strd", "10fg6", "mn2t6", "mx2t6"]
+    # _surf_pp_parameters += ["cin"]
 
-    _parameters_ufunc = {"tp": 'sum',
-                         "10fg6": "max",
+    _not_6 = []
+
+    for par in _surf_pp_parameters:
+        if '6' not in par:
+            _not_6.append(par)
+
+    _to_diff = ["tp", "sshf", "slhf", "ssr", "str", "cp", "ssrd", "strd"]  # accumulated parameters to differentiate
+
+    _parameters_ufunc = {"10fg6": "max",
                          "mn2t6": "min",
                          "mx2t6": "max"}
 
-    _parameters_base = {"tp": 0,
-                        "10fg6": 0,
+    for par in _not_6:
+        _parameters_ufunc[par] = 'sum'
+
+    _parameters_base = {"10fg6": 0,
                         "mn2t6": 0,
                         "mx2t6": 0}
 
-    _parameters_loffset = {"tp": '5H',
-                           "10fg6": 0,
+    for par in _not_6:
+        _parameters_base[par] = 0
+
+    _parameters_loffset = {"10fg6": 0,
                            "mn2t6": 0,
                            "mx2t6": 0}
 
+    for par in _not_6:
+        _parameters_loffset[par] = '5H'
+
     @normalize("parameter", _surf_pp_parameters)
     @normalize("date", "date(%Y%m%d)")
     def __init__(self, date, parameter, kind):
@@ -379,15 +404,17 @@ class TrainingDataForecastSurfacePostProcessed(TrainingDataForecast):
             self.source = cml.load_source("indexed-urls", PerUrlIndex(self._PATTERN), request)
 
     def to_xarray(self, **kwargs):
-        fcs = self.source.to_xarray(**kwargs)
+        fcs = self.source.to_xarray(xarray_open_dataset_kwargs={"backend_kwargs": {"ignore_keys": ["dataType"]}}, **kwargs)
         variables = list(fcs.keys())
         ds_list = list()
         for var in variables:
-            if var == 'tp':  # need to do a finite difference of tp to get the accumulation per step
+            if var in self._to_diff:  # need to do a finite difference to get the accumulation per step
                 da = fcs[var].diff('step')
+            # elif var == 'cin':
+            #     da = fcs[var].isel(step=slice(1, None))
             else:
                 da = fcs[var]
-            if var == 'p10fg6':
+            if var == 'p10fg6':  # remove first step for wind gusts
                 var = var[1:]
 
             if self._parameters_ufunc[var] == "sum":
@@ -407,11 +434,13 @@ class TrainingDataForecastSurfacePostProcessed(TrainingDataForecast):
             ds_list.append(ds_resampled.to_dataset())
 
         ds = xr.merge(ds_list).assign_attrs(fcs.attrs)
-        try:
-            new_ds = ds.rename_vars({'tp': 'tp6'})
-            ds = new_ds
-        except:
-            pass
+        for var in variables:
+            if var in self._not_6:
+                try:
+                    new_ds = ds.rename_vars({var: var + '6'})
+                    ds = new_ds
+                except:
+                    pass
 
         return ds.assign_coords(valid_time=ds.time + ds.step)
 
@@ -442,7 +471,7 @@ class TrainingDataForecastSurfacePostProcessed(TrainingDataForecast):
 
         parameters = list()
         for param in self.parameter:
-            if param != 'tp':
+            if param not in self._not_6:
                 parameters.append(param[:-1])
             else:
                 parameters.append(param)
@@ -525,7 +554,7 @@ class TrainingDataForecastSurfacePostProcessed(TrainingDataForecast):
         for var in obs_fcs.keys():
             if var == 'fg10':
                 var_name[var] = "p10fg6"
-            elif var in ['mn2t', 'mx2t', 'tp']:
+            elif var in ['mn2t', 'mx2t'] or var in self._not_6:
                 var_name[var] = var + '6'
         obs_fcs = obs_fcs.rename_vars(var_name)
 
