@@ -13,7 +13,7 @@ from .training_data_forecasts import TrainingDataForecast, TrainingDataForecastS
     TrainingDataForecastSurfacePostProcessed
 from ..utils import convert_to_datetime
 
-__version__ = "0.1.1"
+__version__ = "0.1.7"
 
 # TODO: Add a check for valid reforecast date and then warn the user if not valid
 
@@ -27,7 +27,7 @@ class TrainingDataReforecast(TrainingDataForecast):
     def get_observations_as_xarray(self, rfcs_kwargs=None, **obs_kwargs):
         if rfcs_kwargs is None:
             rfcs_kwargs = dict()
-        rfcs = self.source.to_xarray(**rfcs_kwargs)
+        rfcs = self.source.to_xarray(xarray_open_dataset_kwargs={"backend_kwargs": {"ignore_keys": ["dataType"]}}, **rfcs_kwargs)
         rfcs_valid_time = rfcs.valid_time.to_pandas()
         rfcs_time_list = list()
         for i in range(rfcs_valid_time.shape[0]):
@@ -42,9 +42,15 @@ class TrainingDataReforecast(TrainingDataForecast):
                 if day not in days[year_month]:
                     days[year_month].append(day)
 
+        if isinstance(self.parameter, (tuple, list)):  # fix for cin observations bug in the dataset, should be solved later at the analysis dataset level
+            parameters = [param for param in self.parameter if param != "cin"]
+        elif self.parameter == "cin":
+            parameters = ""
+        else:
+            parameters = self.parameter
         sources_list = list()
         for year_month in days:
-            request = {"param": self.parameter,
+            request = {"param": parameters,
                        "date": days[year_month],
                        # Parameters passed to the filename mangling
                        "url": self._BASEURL,
@@ -135,7 +141,8 @@ class TrainingDataReforecastSurfacePostProcessed(TrainingDataReforecast, Trainin
     def __init__(self, date, parameter):
 
         TrainingDataForecastSurfacePostProcessed.__init__(self, date, parameter, "ensemble")
-        self._parameters_loffset.update(tp=0)
+        for par in self._not_6:
+            self._parameters_loffset.update({par: 0})
 
     # Warning : function not yet ready !!!!
     def get_observations_as_xarray(self, rfcs_kwargs=None, **obs_kwargs):
@@ -173,7 +180,7 @@ class TrainingDataReforecastSurfacePostProcessed(TrainingDataReforecast, Trainin
 
         parameters = list()
         for param in self.parameter:
-            if param != 'tp':
+            if param not in self._not_6:
                 parameters.append(param[:-1])
             else:
                 parameters.append(param)
@@ -220,6 +227,7 @@ class TrainingDataReforecastSurfacePostProcessed(TrainingDataReforecast, Trainin
         else:
             new_obs = obs
         new_obs = new_obs.stack(datetime=("time", "step")).drop_vars("datetime").swap_dims({"datetime": "time"}).rename({"valid_time": "time"})
+        new_obs = new_obs.where(new_obs['time.year'] >= 1997, drop=True)  # Treats edge cases near the start of 2017
         obs_time = new_obs.time.to_pandas()
         obs_time_list = list(map(convert_to_datetime, obs_time))
         idx = list()
@@ -273,7 +281,7 @@ class TrainingDataReforecastSurfacePostProcessed(TrainingDataReforecast, Trainin
         for var in obs_rfcs.keys():
             if var == 'fg10':
                 var_name[var] = "p10fg6"
-            elif var in ['mn2t', 'mx2t', 'tp']:
+            elif var in ['mn2t', 'mx2t'] or var in self._not_6:
                 var_name[var] = var + '6'
         obs_rfcs = obs_rfcs.rename_vars(var_name)
 
